@@ -739,6 +739,44 @@ class TestExitStack(unittest.TestCase):
             pass
 
 
+    def test_dont_reraise_RuntimeError(self):
+        # https://bugs.python.org/issue27122
+        class UniqueException(Exception): pass
+        class UniqueRuntimeError(RuntimeError): pass
+
+        @contextmanager
+        def second():
+            try:
+                yield 1
+            except Exception as exc:
+                # Py2 compatible explicit exception chaining
+                new_exc = UniqueException("new exception")
+                new_exc.__cause__ = exc
+                raise new_exc
+
+        @contextmanager
+        def first():
+            try:
+                yield 1
+            except Exception as exc:
+                raise exc
+
+        # The UniqueRuntimeError should be caught by second()'s exception
+        # handler which chain raised a new UniqueException.
+        with self.assertRaises(UniqueException) as err_ctx:
+            with ExitStack() as es_ctx:
+                es_ctx.enter_context(second())
+                es_ctx.enter_context(first())
+                raise UniqueRuntimeError("please no infinite loop.")
+
+        exc = err_ctx.exception
+        self.assertIsInstance(exc, UniqueException)
+        self.assertIsInstance(exc.__cause__, UniqueRuntimeError)
+        if check_exception_chaining:
+            self.assertIs(exc.__context__, exc.__cause__)
+            self.assertIsNone(exc.__cause__.__context__)
+            self.assertIsNone(exc.__cause__.__cause__)
+
 
 class TestRedirectStream:
 
